pilas.actores.pingu.Esperando

Package pilas :: Package actores :: Module pingu :: Class Esperando |
[hide private]
[frames] | no frames]

# Class Esperando

source code

                        object --+
                                 |
    comportamientos.Comportamiento --+
                                     |
                                    Esperando

Un actor en posicion normal o esperando a que el usuario pulse alguna tecla.

Instance Methods | [hide private]
iniciar(self, receptor) Se invoca cuando se anexa el comportamiento a un actor. | source code
actualizar(self) Actualiza el comportamiento en un instante dado. | source code
Inherited from `comportamientos.Comportamiento`: `terminar` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### iniciar(self, receptor) | source code
Se invoca cuando se anexa el comportamiento a un actor. :param receptor: El actor que comenzará a ejecutar este comportamiento. Overrides: comportamientos.Comportamiento.iniciar (inherited documentation)

### actualizar(self) | source code
Actualiza el comportamiento en un instante dado. Si este metodo retorna True entonces el actor dejará de ejecutar este comportamiento. Overrides: comportamientos.Comportamiento.actualizar (inherited documentation)